if select(2, UnitClass("player")) ~= "MAGE" then return end
local GetSpellInfo = GetSpellInfo
local UnitPowerMax = UnitPowerMax
local UnitHealth = UnitHealth
local UnitHealthMax = UnitHealthMax
local UnitStat = UnitStat
local math_max = math.max
local ipairs = ipairs
local UnitDebuff = UnitDebuff
local GetSpellBonusDamage = GetSpellBonusDamage
local GetSpellCritChance = GetSpellCritChance

function DrDamage:PlayerData()
	--Health Updates
	self.TargetHealth = { [1] = 0.35 }	
	--Special AB info
	--Evocation
	self.ClassSpecials[GetSpellInfo(12051)] = function()
		return 0.6 * UnitPowerMax("player",0), 0.40, 0.8, 1
	end
	--Torment the Weak
	local snareList = {
	--Hunter snares: Wing Clip, Frost trap, Concussive Shot, 
	(GetSpellInfo(2974)), (GetSpellInfo(13810)), (GetSpellInfo(5116)),
	--Rogue snares: Crippling Poison, Deadly Throw
	(GetSpellInfo(25809)), (GetSpellInfo(26679)),
	--Warrior snares: Hamstring, Piercing Howl
	(GetSpellInfo(1715)), (GetSpellInfo(12323)),
	--Shaman snares: Frost Shock, Earthbind, 
	(GetSpellInfo(8056)), (GetSpellInfo(3600)),
	--Others: Curse of Exhaustion, Mind Flay, Dazed, Desecration, Icy Clutch (from Chilblains)
	(GetSpellInfo(18223)), (GetSpellInfo(15407)), (GetSpellInfo(29703)), (GetSpellInfo(55784)), (GetSpellInfo(50434))
	}
	
	--General
	self.Calculation["MAGE"] = function( calculation, ActiveAuras, BuffTalentRanks, spell )
		if self:GetSetAmount( "Frostfire Garb" ) >= 4 then
			calculation.critM = calculation.critM + 0.025
		end	    
		if self.db.profile.ManaConsumables then --Assumes usage of Mana Sapphires and includes Glyph of Mana Gem
			calculation.manaRegen = calculation.manaRegen + 28.458 * (self:HasGlyph(56367) and 1.4 or 1) * ((self:GetSetAmount( "Frostfire Garb" ) >= 2) and 1.25 or 1)
		end
		if BuffTalentRanks["Torment the Weak"] then
			if ActiveAuras["Snare"] then
				calculation.dmgM = calculation.dmgM * (1 + BuffTalentRanks["Torment the Weak"])
			else
				--Snares that aren't handled actively, i.e. don't trigger updates
				for _,k in ipairs(snareList) do
					if UnitDebuff("target", k) then
						calculation.dmgM = calculation.dmgM * (1 + BuffTalentRanks["Torment the Weak"])
						break
					end	
				end
			end
		end
		if BuffTalentRanks["Molten Fury"] then
			if UnitHealth("target") ~= 0 and (UnitHealth("target") / UnitHealthMax("target")) < 0.35 then
				calculation.dmgM = calculation.dmgM * ( 1 + BuffTalentRanks["Molten Fury"])
			end
		end
		if BuffTalentRanks["Shatter"] and (ActiveAuras["Frozen"] or ActiveAuras["Deep Freeze"]) then
			calculation.critPerc = calculation.critPerc + BuffTalentRanks["Shatter"]
		end		
	end
	local ignite = GetSpellInfo(11119)
	self.Calculation["Ignite"] = function( calculation, value )
		calculation.extraCrit = value
		calculation.extraChanceCrit = true
		calculation.extraTicks = 2
		calculation.extraName = ignite 
	end
	
	--Spell specific
	self.Calculation["Ice Lance"] = function( calculation, ActiveAuras )
		if (ActiveAuras["Frozen"] or ActiveAuras["Deep Freeze"]) then
			--Glyph of Ice Lance
			local bonus = self:HasGlyph(56377) and (self:GetLevels() > 0) and 1 or 0
			calculation.spellDmgM = calculation.spellDmgM  * (3 + bonus)
			calculation.bDmgM = calculation.bDmgM  + 2 + bonus
		end
	end
	self.Calculation["Frostfire Bolt"] = function( calculation, ActiveAuras, Talents )
		--Note: Double dips spell damage from mind mastery
		calculation.spellDmg = calculation.spellDmg - GetSpellBonusDamage(1) + math_max(GetSpellBonusDamage(3),GetSpellBonusDamage(5)) + (UnitStat("player",4) * (Talents["Mind Mastery"] or 0))
		calculation.critPerc = calculation.critPerc - GetSpellCritChance(1) + math_max(GetSpellCritChance(3), GetSpellCritChance(5))
		--Glyph of Frostfire
		if self:HasGlyph( 61205 ) then
			calculation.dmgM_dd = calculation.dmgM_dd * 1.02
			calculation.critPerc = calculation.critPerc + 2
		end
			
	end
	self.Calculation["Arcane Missiles"] = function( calculation, ActiveAuras, _, spell, baseSpell )
		--Glyph of Arcane Missiles
		if self:HasGlyph( 56363 ) then
			calculation.critM = calculation.critM + 0.125
		end
		if ActiveAuras["Missile Barrage"] then
			local cast = spell.castTime or baseSpell.castTime
			calculation.castTime = (cast - 2.5) * (calculation.castTime/cast)
		end
	end
	self.Calculation["Fireball"] = function( calculation )
		--Glyph of Fireball
		if self:HasGlyph( 56368 ) then
			calculation.extraDotDmg = nil
			calculation.critPerc = calculation.critPerc + 5
		end		
	end
	self.Calculation["Frostbolt"] = function( calculation )
		--Glyph of Frostbolt
		if self:HasGlyph( 56370 ) then
			calculation.dmgM = calculation.dmgM * 1.05
		end		
	end
	self.Calculation["Ice Barrier"] = function( calculation )
		--Glyph of Ice Barrier
		if self:HasGlyph( 63095 ) then
			calculation.dmgM = calculation.dmgM * 1.3
		end		
	end
	self.Calculation["Living Bomb"] = function( calculation )
		--Glyph of Living Bomb
		if self:HasGlyph( 63091 ) then
			calculation.hybridCanCrit = true
		end		
	end
	self.Calculation["Mirror Image"] = function( calculation )
		--Glyph of Mirror Image
		if self:HasGlyph(63093) then
			calculation.minDam = calculation.minDam * (4/3)
			calculation.maxDam = calculation.maxDam * (4/3)
			calculation.spellDmgM = calculation.spellDmgM * (4/3)
		end
	end
	self.Calculation["Fire Blast"] = function( calculation, ActiveAuras )
		--Glyph of Fire Blast
		if self:HasGlyph(56369) and (ActiveAuras["Stun"] or ActiveAuras["Deep Freeze"]) then
			calculation.critPerc = calculation.critPerc + 50
		end
	end
	
	--Set Bonuses
	--Sets
	self.SetBonuses["Frostfire Garb"] = { 39491, 39492, 39493, 39494, 39495, 40415, 40416, 40417, 40418, 40419 }

--AURA
--Player
	--Icy Veins
	self.PlayerAura[GetSpellInfo(12472)] = { Mods = { ["castTime"] = function(v) return v/1.2 end } }
	--Arcane Blast
	self.PlayerAura[GetSpellInfo(30451)] = { School = "Arcane", ModType = "Special", NoManual = true }	
	--Arcane Power
	self.PlayerAura[GetSpellInfo(12042)] = { Value = 0.2 }
	--Combustion
	self.PlayerAura[GetSpellInfo(11129)] = { School = { ["Fire"] = true, ["Frostfire"] = true }, Value = 10, Apps = 3, ModType = "critPerc" }
	--Missile Barrage
	self.PlayerAura[GetSpellInfo(44401)] = { ActiveAura = "Missile Barrage", Spells = GetSpellInfo(5143) }
	--Hot Streak
	self.PlayerAura[GetSpellInfo(44445)] = { Update = true, Spells = GetSpellInfo(11366) }
	--Fingers of Frost
	self.PlayerAura[GetSpellInfo(44544)] = { ActiveAura = "Frozen" }	
--Target
	--Frost Nova
	--Frostbite
	--Deep Freeze	
	self.TargetAura[GetSpellInfo(122)]   = self.PlayerAura[GetSpellInfo(44544)]
	self.TargetAura[GetSpellInfo(12494)] = self.PlayerAura[GetSpellInfo(44544)]
	self.TargetAura[GetSpellInfo(44572)] = { ActiveAura = "Deep Freeze" }
--Snares
	--Thunder Clap
	self.TargetAura[GetSpellInfo(47502)] = { ActiveAura = "Snare", Manual = "Snared" }
	--Infected Wounds
	self.TargetAura[GetSpellInfo(58179)] = self.TargetAura[GetSpellInfo(47502)]
	--Frost Fever
	self.TargetAura[GetSpellInfo(55095)] = self.TargetAura[GetSpellInfo(47502)]
	--Slow
	self.TargetAura[GetSpellInfo(31589)] = self.TargetAura[GetSpellInfo(47502)]
	--Frostbolt
	self.TargetAura[GetSpellInfo(116)] = self.TargetAura[GetSpellInfo(47502)]
	--Cone of Cold
	self.TargetAura[GetSpellInfo(120)] = self.TargetAura[GetSpellInfo(47502)]
	--Blast Wave
	self.TargetAura[GetSpellInfo(11113)] = self.TargetAura[GetSpellInfo(47502)]
	--Chilled (Ice and Frost Armor debuff, also Improved Blizzard)
	self.TargetAura[GetSpellInfo(7321)] = self.TargetAura[GetSpellInfo(47502)]
	--Frostfire bolt
	self.TargetAura[GetSpellInfo(47610)] = self.TargetAura[GetSpellInfo(47502)]
--Stuns	
	--Impact
	self.TargetAura[GetSpellInfo(12355)] = { ActiveAura = "Stun", Spells = GetSpellInfo(2136), Manual = GetSpellInfo(47923) }
	--Gouge
	self.TargetAura[GetSpellInfo(1776)] = self.TargetAura[GetSpellInfo(12355)]
	--Repentance
	self.TargetAura[GetSpellInfo(20066)] = self.TargetAura[GetSpellInfo(12355)]
	--Maim
	self.TargetAura[GetSpellInfo(22570)] = self.TargetAura[GetSpellInfo(12355)]
	--Bash
	self.TargetAura[GetSpellInfo(8983)] = self.TargetAura[GetSpellInfo(12355)]
	--Pounce
	self.TargetAura[GetSpellInfo(9005)] = self.TargetAura[GetSpellInfo(12355)]
	--Intimidation
	self.TargetAura[GetSpellInfo(19577)] = self.TargetAura[GetSpellInfo(12355)]
	--Hammer of Justice
	self.TargetAura[GetSpellInfo(10308)] = self.TargetAura[GetSpellInfo(12355)]
	--Stun (Seal of Justice)
	self.TargetAura[GetSpellInfo(20170)] = self.TargetAura[GetSpellInfo(12355)]
	--Kidney Shot
	self.TargetAura[GetSpellInfo(8643)] = self.TargetAura[GetSpellInfo(12355)]
	--Cheap Shot
	self.TargetAura[GetSpellInfo(1833)] = self.TargetAura[GetSpellInfo(12355)]
	--Shadowfury
	self.TargetAura[GetSpellInfo(30283)] = self.TargetAura[GetSpellInfo(12355)]
	--Intercept
	self.TargetAura[GetSpellInfo(30153)] = self.TargetAura[GetSpellInfo(12355)]
	--Charge
	self.TargetAura[GetSpellInfo(7922)] = self.TargetAura[GetSpellInfo(12355)]
	--Concussion Blow
	self.TargetAura[GetSpellInfo(12809)] = self.TargetAura[GetSpellInfo(12355)]
	
	--Arcane Blast
	self.Calculation[GetSpellInfo(30451)] = function( calculation, _, _, _, apps, texture )
		--Check texture to make sure this calc is coming from the buff calculation engine
		if texture and apps then
			calculation.dmgM = calculation.dmgM * (1 + apps * (0.15 + (self:HasGlyph(62210) and 0.03 or 0)))
		end
	end
	
	self.spellInfo = {
	--FIRE
		[GetSpellInfo(11366)] = {
					--DONE: BASE OK, INCREASE OK, COEFFICIENT OK
					["Name"] = "Pyroblast",
					[0] = { School = "Fire", castTime = 5, canCrit = true, eDuration = 12, sTicks = 3, bonusFactor = 1.15, dotFactor = 0.2, BaseIncrease = true },
					[1] = { 141, 187, 114, 114, hybridDotDmg = 56, spellLevel = 20, },
					[2] = { 180, 236, 123, 124, hybridDotDmg = 72, spellLevel = 24, },
					[3] = { 255, 327, 130, 130, hybridDotDmg = 96, spellLevel = 30, },
					[4] = { 329, 419, 132, 132, hybridDotDmg = 124, spellLevel = 36, },
					[5] = { 407, 515, 129, 130, hybridDotDmg = 156, spellLevel = 42, },
					[6] = { 503, 631, 121, 122, hybridDotDmg = 188, spellLevel = 48, },
					[7] = { 600, 750, 109, 110, hybridDotDmg = 228, spellLevel = 54, },
					[8] = { 708, 898, 92, 92, hybridDotDmg = 268, spellLevel = 60, },
					[9] = { 846, 1074, 70, 70, hybridDotDmg = 312, spellLevel = 66, },
					[10] = { 939, 1191, 54, 54, hybridDotDmg = 356, spellLevel = 70, },
					[11] = { 1014, 1286, 40, 41, hybridDotDmg = 384, spellLevel = 73, },
					[12] = { 1190, 1510, 20, 21, hybridDotDmg = 452, spellLevel = 77, },
		},
		[GetSpellInfo(133)] = {
					--DONE: BASE OK, INCREASE OK, COEFFICIENT OK
					["Name"] = "Fireball",
					[0] = { School = "Fire", canCrit = true, castTime = 3.5, eDuration = 8, sTicks = 2, BaseIncrease = true, },
					[1] = { 14, 22, 47, 48, extraDotDmg = 2, spellLevel = 1, eDuration = 4, castTime = 1.5, },
					[2] = { 31, 45, 59, 60, extraDotDmg = 3, spellLevel = 6, eDuration = 6, castTime = 2, },
					[3] = { 53, 73, 68, 68, extraDotDmg = 6, spellLevel = 12, eDuration = 6, castTime = 2.5, },
					[4] = { 84, 116, 80, 81, extraDotDmg = 12, spellLevel = 18, castTime = 3, },
					[5] = { 139, 187, 100, 101, extraDotDmg = 20, spellLevel = 24, },
					[6] = { 199, 265, 105, 105, extraDotDmg = 28, spellLevel = 30, },
					[7] = { 255, 335, 105, 106, extraDotDmg = 32, spellLevel = 36, },
					[8] = { 318, 414, 102, 103, extraDotDmg = 40, spellLevel = 42, },
					[9] = { 392, 506, 96, 96, extraDotDmg = 52, spellLevel = 48, },
					[10] = { 475, 609, 88, 89, extraDotDmg = 60, spellLevel = 54, },
					[11] = { 561, 715, 74, 74, extraDotDmg = 72, spellLevel = 60, },
					[12] = { 596, 760, 76, 76, extraDotDmg = 76, spellLevel = 60, },
					[13] = { 633, 805, 56, 56, extraDotDmg = 84, spellLevel = 66, },
					[14] = { 717, 913, 42, 42, extraDotDmg = 92, spellLevel = 70, },
					[15] = { 783, 997, 27, 28, extraDotDmg = 100, spellLevel = 74, },
					[16] = { 888, 1132, 10, 11, extraDotDmg = 116, spellLevel = 78, },
		},
		[GetSpellInfo(2948)] = {
					--DONE: BASE OK, INCREASE OK, COEFFICIENT OK
					["Name"] = "Scorch",
					[0] = { School = "Fire", canCrit = true, BaseIncrease = true, },
					[1] = { 53, 65, 52, 53, spellLevel = 22, },
					[2] = { 77, 93, 57, 58, spellLevel = 28, },
					[3] = { 100, 120, 59, 60, spellLevel = 34, },
					[4] = { 133, 159, 60, 60, spellLevel = 40, },
					[5] = { 162, 192, 57, 58, spellLevel = 46, },
					[6] = { 200, 239, 53, 54, spellLevel = 52, },
					[7] = { 233, 275, 46, 47, spellLevel = 58, },
					[8] = { 269, 317, 34, 35, spellLevel = 64, },
					[9] = { 305, 361, 25, 25, spellLevel = 70, },
					[10] = { 321, 379, 18, 19, spellLevel = 73, },
					[11] = { 376, 444, 6, 7, spellLevel = 78, },
		},
		[GetSpellInfo(2136)] = {
					--DONE: BASE OK, INCREASE OK, COEFFICIENT OK
					["Name"] = "Fire Blast",
					[0] = { School = "Fire", canCrit = true, Cooldown = 8, BaseIncrease = true },
					[1] = { 24, 32, 44, 45, spellLevel = 6, },
					[2] = { 57, 71, 66, 66, spellLevel = 14, },
					[3] = { 103, 127, 81, 82, spellLevel = 22, },
					[4] = { 168, 202, 90, 90, spellLevel = 30, },
					[5] = { 242, 290, 92, 93, spellLevel = 38, },
					[6] = { 332, 394, 88, 89, spellLevel = 46, },
					[7] = { 431, 509, 78, 78, spellLevel = 54, },
					[8] = { 539, 637, 62, 63, spellLevel = 61, },
					[9] = { 664, 786, 37, 37, spellLevel = 70, },
					[10] = { 760, 900, 24, 24, spellLevel = 74, },
					[11] = { 925, 1095, 0, 0, spellLevel = 80, },					
		},			
		[GetSpellInfo(11113)] = {
					--BASE OK, INCREASE OK, COEFFICIENT X
					["Name"] = "Blast Wave",
					[0] = { School = "Fire", canCrit = true, sFactor = 0.90 * 1/2, Cooldown = 45, BaseIncrease = true },
					[1] = { 154, 186, 50, 50, spellLevel = 30, },
					[2] = { 201, 241, 52, 53, spellLevel = 36, },
					[3] = { 277, 329, 50, 51, spellLevel = 44, },
					[4] = { 365, 433, 44, 45, spellLevel = 52, },
					[5] = { 462, 544, 38, 38, spellLevel = 60, },
					[6] = { 533, 627, 31, 32, spellLevel = 65, },
					[7] = { 616, 724, 23, 23, spellLevel = 70, },
					[8] = { 882, 1038, 16, 17, spellLevel = 75, },
					[9] = { 1047, 1233, 0, 0, spellLevel = 80, },					
		},
		[GetSpellInfo(31661)] = {
					--BASE OK, INCREASE OK, COEFFICIENT X
					["Name"] = "Dragon's Breath",
					[0] = { School = "Fire", canCrit = true, sFactor = 0.90 * 1/2, Cooldown = 20, BaseIncrease = true },
					[1] = { 370, 430, 45, 45, spellLevel = 50, },
					[2] = { 454, 526, 38, 39, spellLevel = 56, },
					[3] = { 574, 666, 28, 29, spellLevel = 64, },
					[4] = { 680, 790, 20, 20, spellLevel = 70, },
					[5] = { 935, 1085, 13, 14, spellLevel = 75, },
					[6] = { 1101, 1279, 0, 0, spellLevel = 80, },
		},			
		[GetSpellInfo(2120)] = {
					--DONE: BASE OK, INCREASE OK, COEFFICIENT OK
					["Name"] = "Flamestrike",
					[0] = { School = "Fire", castTime = 3, canCrit = true, eDuration = 8, sTicks = 2, bonusFactor = 0.2357, dotFactor = 0.488, BaseIncrease = true },
					[1] = { 52, 68, 38, 39, hybridDotDmg = 48, spellLevel = 16, castTime = 2 },
					[2] = { 96, 122, 44, 45, hybridDotDmg = 88, spellLevel = 24, castTime = 2 },
					[3] = { 154, 192, 48, 48, hybridDotDmg = 140, spellLevel = 32, castTime = 2 },
					[4] = { 220, 272, 52, 52, hybridDotDmg = 196, spellLevel = 40, castTime = 2 },
					[5] = { 291, 359, 48, 48, hybridDotDmg = 264, spellLevel = 48, castTime = 2 },
					[6] = { 375, 459, 40, 41, hybridDotDmg = 340, spellLevel = 56, castTime = 2 },
					[7] = { 471, 575, 30, 31, hybridDotDmg = 424, spellLevel = 64, },
					[8] = { 688, 842, 22, 23, hybridDotDmg = 620, spellLevel = 72, },
					[9] = { 873, 1067, 3, 4, hybridDotDmg = 780, spellLevel = 79, },
		},
		[GetSpellInfo(44457)] = {
					--DONE: BASE OK, INCREASE OK, COEFFICIENT OK
					["Name"] = "Living Bomb",
					[0] = { School = "Fire", canCrit = true, eDuration = 12, bonusFactor = 0.4, dotFactor = 0.8, sTicks = 3, },
					[1] = { 306, 306, hybridDotDmg = 612, spellLevel = 60, },
					[2] = { 512, 512, hybridDotDmg = 1024, spellLevel = 70, },
					[3] = { 690, 690, hybridDotDmg = 1380, spellLevel = 80, }, 
		},
		[GetSpellInfo(44614)] = {
					--DONE: BASE OK, INCREASE OK, COEFFICIENT OK
					["Name"] = "Frostfire Bolt",
					[0] = { School = "Frostfire", canCrit = true, castTime = 3, eDuration = 9, sTicks = 3, BaseIncrease = true }, 
					[1] = { 629, 731, 19, 20, extraDotDmg = 60, spellLevel = 75, },
					[2] = { 722, 838, 0, 0, extraDotDmg = 90, spellLevel = 80, },
		},
	--FROST
		[GetSpellInfo(116)] = {
					--DONE: BASE OK, INCREASE OK, COEFFICIENT OK
					["Name"] = "Frostbolt",
					[0] = { School = "Frost", castTime = 3, canCrit = true, bonusFactor = (3/3.5) * 0.95, BaseIncrease = true },
					[1] = { 18, 20, 38, 38, castTime = 1.5, spellLevel = 4, },
					[2] = { 31, 35, 50, 51, castTime = 1.8, spellLevel = 8, },
					[3] = { 51, 57, 59, 60, castTime = 2.2, spellLevel = 14, },
					[4] = { 74, 82, 66, 66, castTime = 2.6, spellLevel = 20, },
					[5] = { 126, 138, 81, 81, spellLevel = 26, },
					[6] = { 174, 190, 81, 82, spellLevel = 32, },
					[7] = { 227, 247, 84, 84, spellLevel = 38, },
					[8] = { 292, 316, 82, 83, spellLevel = 44, },
					[9] = { 353, 383, 78, 78, spellLevel = 50, },
					[10] = { 429, 463, 69, 70, spellLevel = 56, },
					[11] = { 515, 555, 64, 64, spellLevel = 60, },
					[12] = { 536, 578, 54, 55, spellLevel = 63, },
					[13] = { 597, 643, 38, 39, spellLevel = 69, },
					[14] = { 630, 680, 38, 38, spellLevel = 70, },
					[15] = { 702, 758, 21, 21, spellLevel = 75, },
					[16] = { 799, 861, 4, 5, spellLevel = 79, },
		},
		[GetSpellInfo(10)] = {
					--BASE OK, INCREASE OK, COEFFICIENT X
					["Name"] = "Blizzard",
					[0] = { School = "Frost", canCrit = true, castTime = 8, bonusFactor = 1.15, BaseIncrease = true, sTicks = 1, Channeled = true },
					[1] = { 288, 288, 48, 48, spellLevel = 20, },
					[2] = { 504, 504, 80, 80, spellLevel = 28, },
					[3] = { 736, 736, 64, 64, spellLevel = 36, },
					[4] = { 1024, 1024, 80, 80, spellLevel = 44, },
					[5] = { 1328, 1328, 64, 64, spellLevel = 52, },
					[6] = { 1696, 1696, 64, 64, spellLevel = 60, },
					[7] = { 2184, 2184, 32, 32, spellLevel = 68, },
					[8] = { 2800, 2800, 24, 24, spellLevel = 74, },
					[9] = { 3408, 3408, 0, 0, spellLevel = 80, },
		},
		[GetSpellInfo(120)] = {
					--BASE OK, INCREASE OK, COEFFICIENT X
					["Name"] = "Cone of Cold",
					[0] = { School = "Frost", canCrit = true, bonusFactor= 0.214, Cooldown = 10, BaseIncrease = true },
					[1] = { 98, 108, 43, 44, spellLevel = 26, },
					[2] = { 146, 160, 46, 46, spellLevel = 34, },
					[3] = { 203, 223, 45, 46, spellLevel = 42, },
					[4] = { 264, 290, 39, 39, spellLevel = 50, },
					[5] = { 335, 365, 33, 33, spellLevel = 58, },
					[6] = { 410, 448, 25, 26, spellLevel = 66, },
					[7] = { 559, 611, 18, 19, spellLevel = 72, },
					[8] = { 707, 773, 2, 3, spellLevel = 79, },
		},
		[GetSpellInfo(122)] = {
					--BASE OK, INCREASE OK, COEFFICIENT X
					["Name"] = "Frost Nova",
					[0] = { School = "Frost", canCrit = true, bonusFactor = 0.193, Cooldown = 25, BaseIncrease = true, },
					[1] = { 19, 21, 35, 35, spellLevel = 10, },
					[2] = { 33, 37, 27, 27, spellLevel = 26, },
					[3] = { 52, 58, 20, 20, spellLevel = 40, },
					[4] = { 70, 80, 13, 13, spellLevel = 54, },
					[5] = { 230, 260, 6, 7, spellLevel = 67, },
					[6] = { 365, 415, 4, 4, spellLevel = 75, },
		},
		[GetSpellInfo(30455)] = {
					--DONE: BASE OK, INCREASE OK, COEFFICIENT OK
					["Name"] = "Ice Lance",
					[0] = { School = "Frost", canCrit = true, sFactor = 1/3, BaseIncrease = true },
					[1] = { 161, 187, 44, 45, spellLevel = 66, },
					[2] = { 182, 210, 10, 11, spellLevel = 72, },
					[3] = { 221, 255, 2, 3, spellLevel = 78, },
		},			
		[GetSpellInfo(11426)] = {
					--BASE OK, INCREASE OK, COEFFICIENT X
					["Name"] = "Ice Barrier",
					[0] = { School = "Frost", Cooldown = 30, bonusFactor = 0.8053, NoSchoolTalents = true, NoDPS = true, NoDoom = true, Unresistable = true, NoAura = true, NoDPM = true, BaseIncrease = true },
					[1] = { 438, 438, 112, 112, spellLevel = 40, },
					[2] = { 549, 549, 108, 108, spellLevel = 46, },
					[3] = { 678, 678, 100, 100, spellLevel = 52, },
					[4] = { 818, 818, 88, 88, spellLevel = 58, },
					[5] = { 925, 925, 70, 70, spellLevel = 64, },
					[6] = { 1075, 1075, 48, 48, spellLevel = 70, },
					[7] = { 2800, 2800, 75, 75, spellLevel = 75, },
					[8] = { 3300, 3300, 0, 0, spellLevel = 80, },
		},
	-- TODO : Summon Water Elemental
	--ARCANE
		[GetSpellInfo(5143)] = {
					--DONE: BASE OK, INCREASE OK, COEFFICIENT OK
					["Name"] = "Arcane Missiles",
					[0] = { School = "Arcane", canCrit = true, castTime = 5, sHits = 5, BaseIncrease = true, Channeled = true },
					[1] = { 24, 24, 1, 2, castTime = 3, spellLevel = 8, sHits = 3, },
					[2] = { 36, 36, 1, 2, castTime = 4, spellLevel = 16, sHits = 4, },
					[3] = { 56, 56, 2, 2, spellLevel = 24, },
					[4] = { 83, 83, 2, 3, spellLevel = 32, },
					[5] = { 115, 115, 2, 3, spellLevel = 40, },
					[6] = { 151, 151, 3, 4, spellLevel = 48, },
					[7] = { 192, 192, 3, 4, spellLevel = 56, },
					[8] = { 230, 230, 4, 4, spellLevel = 60, },
					[9] = { 240, 240, 4, 5, spellLevel = 63, },
					[10] = { 263, 264, 1, 1, spellLevel = 69, }, --TODO: Still? Blizzard tooltip reports wrong basedamage (real is +3,4)
					[11] = { 280, 280, 5, 6, spellLevel = 70, },
					[12] = { 320, 320, 6, 6, spellLevel = 75, },
					[13] = { 360, 360, 1, 2, spellLevel = 79, },					
		},
		[GetSpellInfo(1449)] = {
					--BASE X, INCREASE OK, COEFFICIENT X
					["Name"] = "Arcane Explosion",
					[0] = { School = "Arcane", canCrit = true, sFactor = 1/2, BaseIncrease = true },
					[1] = { 32, 36, 26, 27, spellLevel = 14, },
					[2] = { 57, 63, 34, 35, spellLevel = 22, },
					[3] = { 97, 105, 45, 45, spellLevel = 30, },
					[4] = { 139, 151, 37, 38, spellLevel = 38, },
					[5] = { 186, 202, 37, 38, spellLevel = 46, },
					[6] = { 243, 263, 33, 34, spellLevel = 54, },
					[7] = { 306, 330, 27, 27, spellLevel = 62, },
					[8] = { 377, 407, 16, 16, spellLevel = 70, },
					[9] = { 481, 519, 8, 8, spellLevel = 76, },
					[10] = { 538, 582, 0, 0, spellLevel = 80, },
		},
		[GetSpellInfo(30451)] = {
					--DONE: BASE OK, INCREASE OK, COEFFICIENT OK
					["Name"] = "Arcane Blast",
					[0] = { School = "Arcane", canCrit = true, castTime = 2.5, BaseIncrease = true },
					[1] = { 842, 978, 80, 80, spellLevel = 64, },
					[2] = { 897, 1041, 47, 48, spellLevel = 71, },
					[3] = { 1047, 1215, 24, 25, spellLevel = 76, },
					[4] = { 1185, 1377, 0, 0, spellLevel = 80, },
		},
		[GetSpellInfo(44425)] = {
					--BASE OK, INCREASE OK, COEFFICIENT OK (or is it 2.5/3.5?)
					["Name"] = "Arcane Barrage",
					[0] = { School = "Arcane",  bonusFactor = 3/3.5, canCrit = true, Cooldown = 3, BaseIncrease = true },
					[1] = { 386, 470, 50, 50, spellLevel = 60, },
					[2] = { 709, 865, 155, 155, spellLevel = 70, },
					[3] = { 936, 1144, 0, 0, spellLevel = 80, },
		},
		--Mirror Image
		--NOTE: information taken from the front page of EJ's thread.  http://elitistjerks.com/f75/t30655-wotlk_complete_mage_compendium_3_1_updated/
		--12 * (88-98 + 0.15c) + 24 * (163-169 + 0.3c) = 12 Fire Blast + 24 Frostbolt
		[GetSpellInfo(55342)] = {
					["Name"] = "Mirror Image",
					[0] = { School = "Arcane", eDot = true, eDuration = 30, bonusFactor = 3 * 3, cooldown = 180, canCrit = true, NoAura = true, NoSchoolTalents = true, },
					[1] = { 3 * 4968, 3 * 5232, spellLevel = 80, },
		},
		[GetSpellInfo(6143)] = {
					--BASE OK, INCREASE OK, COEFFICIENT X
					["Name"] = "Frost Ward",
					[0] = { School = "Frost", bonusFactor = 0.30, NoSchoolTalents= true, NoDPS = true, NoTooltip = true, NoAura = true, Unresistable = true, },
					[1] = { 165, 165, spellLevel = 22, },
					[2] = { 290, 290, spellLevel = 32, },
					[3] = { 470, 470, spellLevel = 42, },
					[4] = { 675, 675, spellLevel = 52, },
					[5] = { 875, 875, spellLevel = 60, },
					[6] = { 1125, 1125, spellLevel = 70, },
					[7] = { 1950, 1950, spellLevel = 79, },
		},
		[GetSpellInfo(543)] = {
					--BASE OK, INCREASE OK, COEFFICIENT X
					["Name"] = "Fire Ward",
					[0] = { School = "Fire", bonusFactor = 0.30, NoSchoolTalents= true, NoDPS = true, NoTooltip = true, NoAura = true, Unresistable = true, },
					[1] = { 165, 165, spellLevel = 20, },
					[2] = { 290, 290, spellLevel = 30, },
					[3] = { 470, 470, spellLevel = 40, },
					[4] = { 675, 675, spellLevel = 50, },
					[5] = { 875, 875, spellLevel = 60, },
					[6] = { 1125, 1125, spellLevel = 69, },
					[7] = { 1950, 1950, spellLevel = 78, },
		},
		[GetSpellInfo(1463)] = {
					--BASE OK, INCREASE OK, COEFFICIENT X
					["Name"] = "Mana Shield",
					[0] = { School = "Arcane", bonusFactor = 0.8053, NoSchoolTalents= true, NoDPS = true, NoTooltip = true, NoAura = true, Unresistable = true, },
					[1] = { 120, 120, spellLevel = 20, },
					[2] = { 210, 210, spellLevel = 28, },
					[3] = { 300, 300, spellLevel = 36, },
					[4] = { 390, 390, spellLevel = 44, },
					[5] = { 480, 480, spellLevel = 52, },
					[6] = { 570, 570, spellLevel = 60, },
					[7] = { 715, 715, spellLevel = 68, },
					[8] = { 1080, 1080, spellLevel = 73, },
					[9] = { 1330, 1330, spellLevel = 79, },
        	},
	}
	self.talentInfo = { 
		--ARCANE:
		--Arcane Focus
		[GetSpellInfo(11222)] = {	[1] = { Effect = 1, Spells = "Arcane", ModType = "hitPerc" }, },
		--Spell Impact (multiplicative, apparently additive for Fireball)
		[GetSpellInfo(11242)] = {	[1] = { Effect = 0.02, Multiply = true, Spells = { "Arcane Explosion", "Arcane Blast", "Blast Wave", "Fire Blast", "Scorch", "Ice Lance", "Cone of Cold" }, }, 
						[2] = { Effect = 0.02, Spells = "Fireball" }, },
		--Torment the Weak
		[GetSpellInfo(29447)] = {	[1] = { Effect = 0.04, Spells = { "Frostbolt", "Fireball", "Frostfire Bolt", "Arcane Missiles", "Arcane Blast", "Arcane Barrage" }, ModType = "Torment the Weak" }, },
		--Arcane Instability
		[GetSpellInfo(15058)] = {	[1] = { Effect = 0.01, Multiply = true, Spells = "All" }, },
		--Arcane Empowerment
		[GetSpellInfo(31579)] = { 	[1] = { Effect = 0.15, Spells = "Arcane Missiles", ModType = "SpellDamage", },
						[2] = { Effect = 0.03, Spells = "Arcane Blast", ModType = "SpellDamage", }, },
		--Mind Mastery
		[GetSpellInfo(31584)] = { 	[1] = { Effect = 0.03, Spells = "Frostfire Bolt", ModType = "Mind Mastery" }, },
		--Spell Power							
		[GetSpellInfo(35578)] = { 	[1] = { Effect = 0.125, Spells = "All", ModType = "critM" }, },
		
		--FIRE:
		--Improved Fire Blast
		[GetSpellInfo(11078)] = { 	[1] = { Effect = -1, Spells = "Fire Blast", ModType = "cooldown", }, },		
		--Incineration
		[GetSpellInfo(18459)] = { 	[1] = { Effect = 2, Spells = { "Fire Blast", "Scorch", "Arcane Blast", "Cone of Cold" }, ModType = "critPerc", }, },		
		--Ignite
		[GetSpellInfo(11119)] = { 	[1] = { Effect = 0.08, Spells = { "Fire", "Frostfire Bolt" }, ModType = "Ignite", }, },		
		--World in Flames
		[GetSpellInfo(11108)] = {	[1] = { Effect = 2, Spells = { "Flamestrike", "Pyroblast", "Blast Wave", "Dragon's Breath", "Living Bomb", "Blizzard", "Arcane Explosion" }, ModType = "critPerc", }, },
		--Improved Scorch
		[GetSpellInfo(11095)] = { 	[1] = { Effect = 1, Spells = { "Scorch", "Fireball", "Frostfire Bolt" }, ModType = "critPerc" }, },
		--Master of Elements
		[GetSpellInfo(29074)] = { 	[1] = { Effect = 0.1, Spells = "All", ModType = "freeCrit" }, },
		
		--Playing with Fire
		[GetSpellInfo(31638)] = { 	[1] = { Effect = 0.01, Spells = "All", }, },		
		--Fire Power (multiplicative, apparently additive for Fireball)
		[GetSpellInfo(11124)] = {	[1] = { Effect = 0.02, Multiply = true, Spells = { "Flamestrike", "Pyroblast", "Blast Wave", "Scorch", "Fire Blast", "Dragon's Breath", "Frostfire Bolt" }, }, 
						[2] = { Effect = 0.02, Spells = "Fireball" }, 
						[3] = { Effect = 0.02, Spells = "Living Bomb", ModType = "dmgM_dd", Multiply = true }, },
		--Molten Fury
		[GetSpellInfo(31679)] = {	[1] = { Effect = 0.06, Spells = "All", ModType = "Molten Fury", }, },
		--Empowered Fire
		[GetSpellInfo(31656)] = { 	[1] = { Effect = 0.05, Spells = { "Fireball", "Frostfire Bolt" }, ModType = "SpellDamage" }, },
		--Burnout
		[GetSpellInfo(44449)] = {	[1] = { Effect = 0.05, Spells = "All", ModType = "critM" }, },
		
		--FROST:
		--Ice Floes
		[GetSpellInfo(31670)] = {	[1] = { Effect = { -1.75, -3.5, 5 }, Spells = "Frost Nova", ModType = "cooldown" },
						[2] = { Effect = { -0.7, -1.4, -2 }, Spells = "Cone of Cold", ModType = "cooldown" }, },
		--Ice Shards
		[GetSpellInfo(11207)] = { 	[1] = { Effect = { 1/6, 1/3, 0.5 }, Spells = { "Frost", "Frostfire Bolt" }, ModType = "critM", }, },
		--Precision
		[GetSpellInfo(29438)] = { 	[1] = { Effect = 1, Spells = "All", ModType = "hitPerc" }, },
		--Permafrost
		[GetSpellInfo(11175)] = { 	[1] = { Effect = { 0, 3, 3 }, Spells = "Frostfire Bolt", ModType = "eDuration" }, },
		--Piercing Ice
		[GetSpellInfo(11151)] = { 	[1] = { Effect = 0.02, Multiply = true, Spells = { "Frost", "Frostfire Bolt" }, }, },		
		--Shatter
		[GetSpellInfo(11170)] = { 	[1] = { Effect = { 17, 34, 50 }, Spells = "All", ModType = "Shatter" }, },		
		--Improved Cone of Cold
		[GetSpellInfo(11190)] = { 	[1] = { Effect = { 0.15, 0.25, 0.35 }, Spells = "Cone of Cold", }, },
		--Cold as Ice
		[GetSpellInfo(55091)] = {	[1] = { Effect = { -3, -6 }, Spells = "Ice Barrier", ModType = "cooldown" }, },
		--Winter's Chill
		[GetSpellInfo(11180)] = { 	[1] = { Effect = 1, Spells = "Frostbolt", ModType = "critPerc" }, },		
		--Arctic Winds
		[GetSpellInfo(31674)] = { 	[1] = { Effect = 0.01, Multiply = true, Spells = { "Frost", "Frostfire Bolt" }, }, },		
		--Empowered Frostbolt
		[GetSpellInfo(31682)] = { 	[1] = { Effect = 0.05, Spells = "Frostbolt", ModType = "SpellDamage" }, },
		--Chilled to the Bone
		[GetSpellInfo(44566)] = { 	[1] = { Effect = 0.01, Multiply = true, Spells = { "Frostbolt", "Frostfire Bolt", "Ice Lance" }, }, },
	}
end